@@ -84,27 +84,28 @@ class DataSet(pd.DataFrame):
         self._spacegroup = None
         self._cell = None
         self._merged = None
-        
-        if isinstance(data, DataSet):
-            self.__finalize__(data)
 
-        elif isinstance(data, gemmi.Mtz):
+        # Construct DataSet from gemmi.Mtz object
+        if isinstance(data, gemmi.Mtz):
             from reciprocalspaceship import io
             dataset = io.from_gemmi(data)
-            self.__finalize__(dataset)
             data = dataset
 
-        # Provided values for DataSet attributes take precedence
-        if spacegroup:
-            self._spacegroup = spacegroup
-        if cell:
-            self._cell = cell
-        if merged is not None:
-            self._merged = merged
-            
-        # Build DataSet using DataFrame.__init__()
         super().__init__(data=data, index=index, columns=columns,
                          dtype=dtype, copy=copy)
+
+        # Copy over _metadata if present in provided data
+        if isinstance(data, DataSet):
+            self.__finalize__(data)
+            
+        # Provided values for DataSet _metadata take precedence
+        if spacegroup:
+            self.spacegroup = spacegroup
+        if cell:
+            self.cell = cell
+        if merged is not None:
+            self.merged = merged
+            
         return
 
     #-------------------------------------------------------------------
@@ -148,7 +149,6 @@ class DataSet(pd.DataFrame):
         else:
             raise ValueError(f"Cannot construct gemmi.UnitCell from value: {val}")
             
-            
     @property
     def merged(self):
         """Whether DataSet contains merged reflection data (boolean)"""
@@ -158,6 +158,20 @@ class DataSet(pd.DataFrame):
     def merged(self, val):
         self._merged = val
 
+    @property
+    def centrics(self):
+        """Access centric reflections in DataSet"""
+        if 'CENTRIC' in self:
+            return self.loc[self.CENTRIC]
+        return self.loc[self.label_centrics().CENTRIC]
+
+    @property
+    def acentrics(self):
+        """Access acentric reflections in DataSet"""
+        if 'CENTRIC' in self:
+            return self.loc[~self.CENTRIC]
+        return self.loc[~self.label_centrics().CENTRIC]
+    
     #-------------------------------------------------------------------
     # Methods
 
